]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - image.h
Support file symlinks inside pk3 files. Directory symlinks, as well as symlinks with...
[xonotic/darkplaces.git] / image.h
diff --git a/image.h b/image.h
index a25f2201193578df8475f1ed8ad10f2c11f0dc11..983581243042e538cf02aa83f3a20a084cd08757 100644 (file)
--- a/image.h
+++ b/image.h
@@ -15,70 +15,37 @@ void Image_CopyMux(unsigned char *outpixels, const unsigned char *inpixels, int
 // applies gamma correction to RGB pixels, in can be the same as out
 void Image_GammaRemapRGB(const unsigned char *in, unsigned char *out, int pixels, const unsigned char *gammar, const unsigned char *gammag, const unsigned char *gammab);
 
-// converts 8bit image data to RGBA, in can not be the same as out
-void Image_Copy8bitRGBA(const unsigned char *in, unsigned char *out, int pixels, const unsigned int *pal);
+// converts 8bit image data to BGRA, in can not be the same as out
+void Image_Copy8bitBGRA(const unsigned char *in, unsigned char *out, int pixels, const unsigned int *pal);
 
-// makes a RGBA mask from RGBA input, in can be the same as out
-int image_makemask (const unsigned char *in, unsigned char *out, int size);
+void Image_StripImageExtension (const char *in, char *out, size_t size_out);
 
-unsigned char *LoadTGA (const unsigned char *f, int filesize, int matchwidth, int matchheight);
+// called by conchars.tga loader in gl_draw.c, otherwise private
+unsigned char *LoadTGA_BGRA (const unsigned char *f, int filesize);
 
 // loads a texture, as pixel data
-unsigned char *loadimagepixels (const char *filename, qboolean complain, int matchwidth, int matchheight);
+unsigned char *loadimagepixelsbgra (const char *filename, qboolean complain, qboolean allowFixtrans);
 
 // loads a texture, as a texture
-rtexture_t *loadtextureimage (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
+rtexture_t *loadtextureimage (rtexturepool_t *pool, const char *filename, qboolean complain, int flags, qboolean allowFixtrans);
 
-// loads a texture's alpha mask, as pixel data
-unsigned char *loadimagepixelsmask (const char *filename, qboolean complain, int matchwidth, int matchheight);
+// writes an upside down BGR image into a TGA
+qboolean Image_WriteTGABGR_preflipped (const char *filename, int width, int height, const unsigned char *data, unsigned char *buffer);
 
-// loads a texture's alpha mask, as a texture
-rtexture_t *loadtextureimagemask (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
-
-// loads a texture and it's alpha mask at once (NULL if it has no translucent pixels)
-extern rtexture_t *image_masktex;
-extern rtexture_t *image_nmaptex;
-rtexture_t *loadtextureimagewithmask (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
-rtexture_t *loadtextureimagewithmaskandnmap (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags, float bumpscale);
-rtexture_t *loadtextureimagebumpasnmap (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags, float bumpscale);
-
-// writes a RGB TGA that is already upside down (which TGA wants)
-qboolean Image_WriteTGARGB_preflipped (const char *filename, int width, int height, const unsigned char *data, unsigned char *buffer);
-
-// writes a RGB TGA
-void Image_WriteTGARGB (const char *filename, int width, int height, const unsigned char *data);
-
-// writes a RGBA TGA
-void Image_WriteTGARGBA (const char *filename, int width, int height, const unsigned char *data);
-
-// returns true if the image has some translucent pixels
-qboolean Image_CheckAlpha(const unsigned char *data, int size, qboolean rgba);
+// writes a BGRA image into a TGA file
+void Image_WriteTGABGRA (const char *filename, int width, int height, const unsigned char *data);
 
 // resizes the image (in can not be the same as out)
-void Image_Resample (const void *indata, int inwidth, int inheight, int indepth, void *outdata, int outwidth, int outheight, int outdepth, int bytesperpixel, int quality);
+void Image_Resample32(const void *indata, int inwidth, int inheight, int indepth, void *outdata, int outwidth, int outheight, int outdepth, int quality);
 
 // scales the image down by a power of 2 (in can be the same as out)
-void Image_MipReduce(const unsigned char *in, unsigned char *out, int *width, int *height, int *depth, int destwidth, int destheight, int destdepth, int bytesperpixel);
-
-// only used by menuplyr coloring
-unsigned char *LoadLMP (const unsigned char *f, int filesize, int matchwidth, int matchheight, qboolean loadAs8Bit);
-
-void Image_HeightmapToNormalmap(const unsigned char *inpixels, unsigned char *outpixels, int width, int height, int clamp, float bumpscale);
-
-typedef struct imageskin_s
-{
-       unsigned char *basepixels;int basepixels_width;int basepixels_height;
-       unsigned char *nmappixels;int nmappixels_width;int nmappixels_height;
-       unsigned char *glowpixels;int glowpixels_width;int glowpixels_height;
-       unsigned char *glosspixels;int glosspixels_width;int glosspixels_height;
-       unsigned char *pantspixels;int pantspixels_width;int pantspixels_height;
-       unsigned char *shirtpixels;int shirtpixels_width;int shirtpixels_height;
-       unsigned char *maskpixels;int maskpixels_width;int maskpixels_height;
-}
-imageskin_t;
-
-int image_loadskin(imageskin_t *s, char *name);
-void image_freeskin(imageskin_t *s);
+void Image_MipReduce32(const unsigned char *in, unsigned char *out, int *width, int *height, int *depth, int destwidth, int destheight, int destdepth);
+
+void Image_HeightmapToNormalmap_BGRA(const unsigned char *inpixels, unsigned char *outpixels, int width, int height, int clamp, float bumpscale);
+
+// console command to fix the colors of transparent pixels (to prevent weird borders)
+void Image_FixTransparentPixels_f(void);
+extern cvar_t r_fixtrans_auto;
 
 #endif